@@ -6,8 +6,6 @@ from ground.hints import (Coordinate,
                           Point)
 
 Expansion = Sequence[Coordinate]
-BinaryCoordinatesOperation = Callable[[Coordinate, Coordinate], Coordinate]
-UnaryOperation = Callable[[Coordinate], Coordinate]
 Range = TypeVar('Range')
-TernaryPointFunction = Callable[[Point, Point, Point], Range]
 QuaternaryPointFunction = Callable[[Point, Point, Point, Point], Range]
+UnaryCoordinateOperation = Callable[[Coordinate], Coordinate]
